### Name: Build Views
### Title: Create or add to a BLViews object
### Aliases: addBLViews addCOPViews BLViews COPViews newPMatrix
### Keywords: datagen manip

### ** Examples

    ### example from Thomas M. Idzorek's paper "A STEP-BY-STEP GUIDE TO THE BLACK-LITTERMAN MODEL"
 
    pick <- newPMatrix(letters[1:8], 3)
    pick[1,7] <- 1
    pick[2,1] <- -1 
    pick[2,2] <- 1
    pick[3, 3:6] <- c(0.9, -0.9, .1, -.1)
    confidences <- 1 / c(0.00709, 0.000141, 0.000866)
    myViews <- BLViews(pick, q = c(0.0525, 0.0025, 0.02), confidences, letters[1:8])
    myViews
    
    ### Modified COP example from Meucci's "Beyond Black-Litterman: Views on non-normal markets" 
    dispersion <- c(.376,.253,.360,.333,.360,.600,.397,.396,.578,.775) / 1000
    sigma <- BLCOP:::.symmetricMatrix(dispersion, dim = 4)
    caps <- rep(1/4, 4)
    mu <- 2.5 * sigma 
    dim(mu) <- NULL
    marketDistribution <- mvdistribution("mt", mean = mu, S = sigma, df = 5 )
    pick <- newPMatrix(c("SP", "FTSE", "CAC", "DAX"), 1)
    pick[1,4] <- 1
    vdist <- list(distribution("unif", min = -0.02, max = 0))
    views <- COPViews(pick, vdist, 0.2, c("SP", "FTSE", "CAC", "DAX"))



